<?PHP
/**
 * Constains lists for resolving literal entry types to the expected IDs.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides lists for categorizing spelled out entry types.
 */
final class MDConcEntryTypes implements MDImporterConcordanceListInterface {

    private const ENTRY_TYPES_VERBOSE = [

        // 0: No known entry type
        "" => "0",
        "ABM 95" => "0",
        "Angebot" => "0",
        "g" => "0",
        "Herkunft unklar" => "0",
        "keine Angaben" => "0",
        "unbenannt" => "0",
        "unbekannt" => "0",
        "Unbekannt" => "0",
        "05.03.07" => "0",
        "22.09.2009" => "0",
        "23.09.2009" => "0",
        "1959" => "0",
        "Zugangsart (MPlus) - als: (MDigital" => "0",

        // 1: Donation
        "Ajándék" => "1",
        "Ajándékozás" => "1",
        "ajándékozás" => "1",
        "Donation" => "1",
        "Geschenk" => "1",
        "Geschenk 2010" => "1",
        "Geschenk 20.10.03" => "1",
        "Schenkung" => "1",
        "Schenkung an" => "1",
        "Schenkung-Ver" => "1",
        "Schenkung 2010" => "1",
        "Schenkung-BB" => "1",
        "Schenkung/ Kauf" => "1",
        "Schenkung an den Förderverein" => "1",
        "Schenkung Briefkasten Museum" => "1",
        "Schenkung 03/06 v.Ostereiermarkt" => "1",
        "Schenkung von Johannes Cornel" => "1",
        "Spende" => "1",
        "Überlassung" => "1",
        "Übertragung" => "1",
        "Spendenquittung" => "1",
        "Spendenbescheinigung" => "1",
        "Передача" => "1", // UK: Transfer
        "передача" => "1", // UK: Transfer
        "Передавання"  => "1", // UK: Transmission.
        "Передавання." => "1", // UK: Transmission.
        "Передано Інститутом археології АН УРСР (нині – ІА НАНУ" => "1", // Submitted by the Institute of Archeology of the Academy of Sciences of the Ukrainian SSR (now - IA of the National Academy of Sciences
        "Передано Інститутом археології АН УРСР (нині - ІА НАНУ" => "1",  // Submitted by the Institute of Archeology of the Academy of Sciences of the Ukrainian SSR (now - IA of the National Academy of Sciences
        "Передано з фондів Державного історичного музею УРСР" => "1", // Transferred from the funds of the State Historical Museum of the Ukrainian SSR

        // 2: Purchase
        "Ankauf" => "2",
        "3Ankauf" => "2",
        "Ankauf Peitz" => "2",
        "Ankauf Sagar" => "2",
        "Bought" => "2",
        "Bestellung" => "2",
        "Kauf Verein" => "2",
        "Einkauf" => "2",
        "Einzelkauf" => "2",
        "Erwerb" => "2",
        "Gekauft" => "2",
        "Kauf" => "2",
        "Kauf  2006" => "2",
        "Kauf 2009" => "2",
        "Kauf d.Förderverein" => "2",
        "Kauf durch Förderverein" => "2",
        "Kauf d. Förderverein" => "2",
        "Kauf Förderverein" => "2",
        "Kauf-Verein" => "2",
        "Purchase" => "2",
        "Sammelankauf" => "2",
        "Sammelkauf" => "2",
        "unterstützter Kauf" => "2",
        "Überweisung" => "2",
        "Vásárlás" => "2",
        "vásárlás" => "2",
        "Vétel" => "2",
        "vétel" => "2",

        // 3: Excavation
        "Excavation" => "3",
        "Feltárás" => "3",
        "Grabung" => "3",
        "Grabungsfund Arch. Landesamt" => "3",

        // 4: Emergenccy Rescue
        "Notbergung" => "4",

        // 5: Inheritance
        "Erbgang" => "5",
        "Erbschaft" => "5",
        "Inheritance" => "5",
        "Nachlass" => "5",
        "Nachlass Angenete" => "5",
        "nachlass angenete" => "5",
        "Nachlass Dr. Enste" => "5",
        "Stiftung/Nachlass" => "5",
        "Übergabe & Nachlass lt. Testament" => "5",
        "Vermächtnis" => "5",
        "Erbschaft / Nachlass" => "5",
        "Hagyaték" => "5",
        "hagyaték" => "5",

        // 6: Endowment
        "Endowment" => "6",
        "Stiftung" => "6",
        "Hivatalos átadás" => "6",

        // Disposession
        "Dispossession" => "7",
        "Enteignung" => "7",

        // 8: Original condition
        "Gyűjtés" => "8",
        "Original condition" => "8",
        "Stammeinlage" => "8",
        "Ursprungsbestand" => "8",

        // 9: Loan
        "Leihgabe" => "9",
        "Leihgabwe" => "9",
        "Leiggabe" => "9",
        "Leihnahme" => "9",
        "Loan" => "9",
        "Verliehen" => "9",
        "Leihgabe vom" => "9",

        // 10: Exchange
        "Austausch" => "10",
        "Csere" => "10",
        "csere" => "10",
        "Exchange" => "10",
        "Tausch" => "10",

        // 11: In-house production
        "Abzüge von alten Negativen" => "11",
        "Anfertigung" => "11",
        "Auftragsarbeit" => "11",
        "Eigenfertigung" => "11",
        "Eigenfertigung des Museums" => "11",
        "Eigenproduktion" => "11",
        "Fotokopie" => "11",
        "hausintern" => "11",
        "In-house production" => "11",
        "Neuanfertigung" => "11",
        "Herstellung" => "11",
        "Hergestellt im Auftrag des Heimatvereins" => "11",
        "Saját előállítás" => "11",
        "Xerox-Kopie" => "11",

        // 12: Material Strain (Törzsanyag)
        "Törzsanyag" => "12",

        // 14: Vorlass
        "Átadás" => "14",
        "Vorlass" => "14",

        // 15: Finding
        "Finding" => "15",
        "Fund" => "15",
        "Fundstück" => "15",
        "Räumung" => "15",
        "Sperrmüll" => "15",

        // 16: Permanent Loan
        "Dauerleihe" => "16",
        "Dauerleihgabe" => "16",
        "Dauerausleihe" => "16",
        "Letét" => "16",
        "Tartós leltét" => "16",

        // 98: Other legal acquisition
        "Altbestand" => "98",
        "alter Bestand" => "98",
        "Alter Bestand" => "98",
        "Altbestand Kapitulationsmuseum" => "98",
        "Altbestand, Zugangsart unbekannt" => "98",
        "Altbestand, Herkunft unklar" => "98",
        "gefunden im Großdepot R. 104" => "98",
        "Museums Altbestand" => "98",
        "Depotfund" => "98",
        "Sanierungsbestand Hornmoldhaus" => "98",
        "To be checked" => "98",
        "Eigentum" => "98",
        "Ungeklärt" => "98",
        "unklar" => "98",
        "unklar, aus dem alten Bestand" => "98",
        "?" => "98",
        "Zugang ungeklärt" => "98",

        // 99: Other legal acquisition
        "Anderer rechtmäßiger Zugang" => "99",
        "Bodenreform" => "99",
        "Other legal acquisition" => "99",
        "Egyéb hivatalos megszerzés" => "99",
        "Zurückgegeben" => "99",
        "Übernahme" => "99",
        "Ünernahme" => "99",
        "Übergabe" => "99",
        "gyűjtés" => "99",

    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return string
     */
    public static function getConcordanceTarget(string $input):string {

        if (!isset(self::ENTRY_TYPES_VERBOSE[$input])) {
            throw new MDImporterMissingConcordance("Unknown entry type: " . $input);
        }

        return self::ENTRY_TYPES_VERBOSE[$input];

    }
}
